Searched refs:__T (Results 1 – 7 of 7) sorted by relevance
| /freebsd-14.2/share/mk/ |
| H A D | src.opts.mk | 293 .if ${__T} == "i386" || ${__T} == "amd64" 299 .if ${__T:Marm*} == "" && ${__T:Mriscv64*} == "" 305 .if (${__T} == "amd64" || ${__T:Maarch64*} != "" || ${__T} == "powerpc64") 311 .if ${__T:Mpowerpc*} || ${__T} == "i386" 319 .if ${__T} != "powerpc64" && ${__T} != "amd64" && ${__T} != "aarch64" 323 .if (${__T:Marm*} == "" && ${__T:Mpowerpc*} == "") || ${__T} == "powerpc64le" 335 .if ${__T} == "aarch64" || ${__T} == "amd64" || ${__T:Mpowerpc64*} != "" 341 .if ${__T} != "aarch64" && ${__T} != "amd64" && ${__T} != "i386" && \ 347 .if ${__T} != "amd64" && ${__T} != "i386" && ${__T} != "aarch64" 351 .if ${__T} == "aarch64" || ${__T} == "amd64" || ${__T} == "i386" || \ [all …]
|
| /freebsd-14.2/contrib/llvm-project/clang/lib/Headers/cuda_wrappers/ |
| H A D | algorithm | 77 template <class __T, class __Cmp> 79 inline _CPP14_CONSTEXPR __host__ __device__ const __T & 80 max(const __T &__a, const __T &__b, __Cmp __cmp) { 84 template <class __T> 86 inline _CPP14_CONSTEXPR __host__ __device__ const __T & 87 max(const __T &__a, const __T &__b) { 91 template <class __T, class __Cmp> 93 inline _CPP14_CONSTEXPR __host__ __device__ const __T & 94 min(const __T &__a, const __T &__b, __Cmp __cmp) { 98 template <class __T> [all …]
|
| /freebsd-14.2/contrib/llvm-project/clang/lib/Headers/ |
| H A D | __clang_cuda_texture_intrinsics.h | 184 template <class __T> struct __TypeInfoT { 185 using __base_t = decltype(__T::x); 461 template <class __T> 483 template <class __T> 505 template <class __T> 661 template <class __op, class __T, class... __Args> 664 using __FetchT = typename __TypeInfoT<__T>::__fetch_t; 665 *__ptr = __convert<__T, __FetchT>::__run( 674 template <class __T> 686 using __FetchT = typename __TypeInfoT<__T>::__fetch_t; [all …]
|
| H A D | __clang_hip_cmath.h | 270 template <class __T> struct __hip_enable_if<true, __T> { typedef __T type; }; 374 template <typename __T> struct is_same<__T, __T> : public true_type {}; 376 template <typename __T> struct add_rvalue_reference { typedef __T &&type; }; 378 template <typename __T> typename add_rvalue_reference<__T>::type declval(); 571 template <typename __T> 574 frexp(__T __x, int *__exp) { 578 template <typename __T> 581 ldexp(__T __x, int __exp) { 585 template <typename __T> 613 template <typename __T> [all …]
|
| H A D | __clang_cuda_cmath.h | 208 template<bool __B, class __T = void> 211 template <class __T> struct __clang_cuda_enable_if<true, __T> { 212 typedef __T type; 317 template <typename __T> 320 frexp(__T __x, int *__exp) { 324 template <typename __T> 327 ldexp(__T __x, int __exp) { 340 template <typename __T> 343 scalbln(__T __x, long __exp) { 347 template <typename __T> [all …]
|
| /freebsd-14.2/contrib/llvm-project/libcxx/include/__format/ |
| H A D | unicode.h | 327 (__next == __property::__V || __next == __property::__T)) // GB7 in __at_extended_grapheme_cluster_break() 330 …if ((__prev == __property::__LVT || __prev == __property::__T) && __next == __property::__T) // GB8 in __at_extended_grapheme_cluster_break()
|
| H A D | extended_grapheme_cluster_table.h | 93 __T, enumerator
|